==> haskell-transformers-compat-0.7.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 transformers-compat
version:              0.7.1
visibility:           public
id:                   transformers-compat-0.7.1-27E2wCklav6CMkj1Ns7rzE
key:                  transformers-compat-0.7.1-27E2wCklav6CMkj1Ns7rzE
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/transformers-compat/
synopsis:             A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.

    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.

    Note: missing methods are not supplied, but this at least permits the types to be used.

category:             Compatibility
abi:                  cc6f60bec0c15a93302d687e9f1af68d
exposed:              True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal

hidden-modules:       Paths_transformers_compat
import-dirs:          /usr/lib/ghc-9.0.1/site-local/transformers-compat-0.7.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/transformers-compat-0.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/transformers-compat-0.7.1
hs-libraries:         HStransformers-compat-0.7.1-27E2wCklav6CMkj1Ns7rzE
depends:              base-4.15.0.0 ghc-prim-0.7.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock

haddock-html:         /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-compat-0.7.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 transformers-compat
version:              0.7.2
visibility:           public
id:                   transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH
key:                  transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/transformers-compat/
synopsis:             A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.

    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.

    Note: missing methods are not supplied, but this at least permits the types to be used.

category:             Compatibility
abi:                  7b2793f26a1178ce136c755c4f5a82ce
exposed:              True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal

hidden-modules:       Paths_transformers_compat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/transformers-compat-0.7.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/transformers-compat-0.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-transformers-compat
hs-libraries:         HStransformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH
depends:              base-4.15.1.0 ghc-prim-0.7.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock

haddock-html:         /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
